﻿using System;
using System.Diagnostics;
using System.Drawing;
using ThinkGeo.MapSuite.Core;

namespace ValueStylesTest
{
    class Program
    {
        static void Main(string[] args)
        {
            ShapeFileFeatureLayer shapeFileFeatureLayer = new ShapeFileFeatureLayer(@"..\..\data\usstates.shp");
            ValueStyle valueStyle = new ValueStyle();
            valueStyle.ColumnName = "colour_map";
            valueStyle.ValueItems.Add(new ValueItem("1", AreaStyles.CreateSimpleAreaStyle(GeoColors.Red)));
            valueStyle.ValueItems.Add(new ValueItem("2", AreaStyles.CreateSimpleAreaStyle(GeoColors.Yellow)));
            valueStyle.ValueItems.Add(new ValueItem("3", AreaStyles.CreateSimpleAreaStyle(GeoColors.Green)));
            shapeFileFeatureLayer.FeatureSource.CustomColumnFetch += FeatureSource_CustomColumnFetch;
            shapeFileFeatureLayer.ZoomLevelSet.ZoomLevel01.CustomStyles.Add(valueStyle);
            shapeFileFeatureLayer.ZoomLevelSet.ZoomLevel01.CustomStyles.Add(TextStyles.City1("colour_map"));
            shapeFileFeatureLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
            shapeFileFeatureLayer.Open();

            Bitmap bitmap = new Bitmap(600, 800);
            GdiPlusGeoCanvas canvas = new GdiPlusGeoCanvas();
            canvas.BeginDrawing(bitmap, new RectangleShape(-140, 60, -70, 20), GeographyUnit.DecimalDegree);
            shapeFileFeatureLayer.Draw(canvas, new System.Collections.ObjectModel.Collection<SimpleCandidate>());
            canvas.EndDrawing();
            bitmap.Save("result.bmp");
            Process.Start("result.bmp");
        }

        static void FeatureSource_CustomColumnFetch(object sender, CustomColumnFetchEventArgs e)
        {
            ShapeFileFeatureSource featureSource = (ShapeFileFeatureSource)sender;
            
            if (e.ColumnName == "colour_map")
            {
                if (Convert.ToInt32(e.Id) < 20)
                {
                    e.ColumnValue = "1";
                }
                else if (Convert.ToInt32(e.Id) < 40)
                {
                    e.ColumnValue = "2";
                }
                else
                {
                    e.ColumnValue = "3";
                }
            }
        }
    }
}
